/* Created by Ville-Petteri Makinen
   email: vpmakine@gmail.com */

#include "medusa.local.h"

/*
 *
 */
string
medusa::version() {
  return ("532.numero.20210105");
}
